<?php

/**  // € // to identify files as UTF8
 * Set an anchor where you need one
 *
 * @module          anchor
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.05.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/anchor.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3060
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


// define global array with template related info
	$anchor_templateInfo = array();


/** ------------------------------------------------------------------------------------
 * build section list for a given page
 * @return	array		$list		= result
 * @param	int			$page_id	= page_id from where you want the sections
 * @param	array		$list		= available result so far
 * @param	string		$keyPrefixPage	= prefix string in front of page key
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= section id)
 * @param	array		$disableModules	== array of modules to be removed from section list
 * @param	array		$anchor_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'anchor_build_section_list' ) == FALSE ):
	function anchor_build_section_list( $page_id = 0, $list = array(), $keyPrefixPage = '', $keyPrefix = '', $disableModules = array(), $anchor_vars = array() )
	{
		// The input page_id may start with a prefix like "P1"
		// The prefix has to be removed first
		$page_id = (int) str_replace( $keyPrefixPage, '', $page_id );

		// page id is 0 or empty
		if (( is_numeric( $page_id )	== FALSE )
		 or ( $page_id					<= 0     )):
			return ( anchor_finalize_section_list( 0, $list, $anchor_vars ));
		endif;

		// get current page
		$query = 'SELECT * '
				. ' FROM ' . TABLE_PREFIX . 'pages'
				. ' WHERE `page_id` = ' . $page_id
				. ' LIMIT 1'
				;
		$page = anchor_execute_query( __FUNCTION__, $query, 'get_all_one', $anchor_vars );
		if ( count( $page ) == 0 ):
			return ( anchor_finalize_section_list( $page_id, $list,$anchor_vars ));
		endif;

		// get list of sections for input page
		$query = 'SELECT * '
				. ' FROM ' . TABLE_PREFIX . 'sections'
				. ' WHERE `page_id` = ' . $page_id
				. ' ORDER BY `position`'
				;
		$sections = anchor_execute_query( __FUNCTION__, $query, 'get_all', $anchor_vars );
		if ( count( $sections ) == 0 ):
			return ( anchor_finalize_section_list( $page_id, $list, $anchor_vars ));
		endif;

		// build output
		$isDisabled = 0;
		foreach ( $sections as $index => $section ):
			// check for disabledModuls
			if ( in_array( $section[ 'module' ], $disableModules ) == TRUE ):
				$isDisabled = 1;
				// read next
				continue;
			endif;

			// get block name
			anchor_get_section_block( $page, $section, $anchor_vars );

			// prepare
			if ( $section[ 'publ_start' ]	> 0 ):
				$section[ 'publ_start' ] = date( DATE_FORMAT . ', ' . TIME_FORMAT, $section[ 'publ_start' ] );
			else:
				$section[ 'publ_start' ] = '...';
			endif;
			if ( $section[ 'publ_end' ]	> 0 ):
				$section[ 'publ_end' ] = date( DATE_FORMAT . ', ' . TIME_FORMAT, $section[ 'publ_end' ] );
			else:
				$section[ 'publ_end' ] = '...';
			endif;

			// build layout string
			anchor_get_section_layout( $section, $anchor_vars );

			// add layout string to list
			$list[ $keyPrefix . $section[ 'section_id' ] ] = $section[ 'SHOW' ];
		endforeach;

		// return the list
		return ( anchor_finalize_section_list( $page_id, $list, $isDisabled, $anchor_vars ));
	}
endif;


/** ------------------------------------------------------------------------------------
 * set layout for section line
 * @return	array		&$section as reference
 * @param	array		$section
 * @param	array		$anchor_vars
 *
 * Note: This is done in a separate function in order that just this function can be replaced if wanted
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'anchor_get_section_layout' ) == FALSE ):
	function anchor_get_section_layout( &$section, $anchor_vars )
	{
		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $anchor_vars ) > 0 )
		and ( array_key_exists( 'MOD_ANCHOR', $anchor_vars ) == TRUE )):
			$MOD_ANCHOR = $anchor_vars[ 'MOD_ANCHOR' ];
		endif;

		$valid = '';
		if (( $section[ 'publ_start' ] != '...' )
		 or ( $section[ 'publ_end' ]   != '...' )):
		 	$valid = ' | ' . $MOD_ANCHOR['valid'] . ' ' . $section[ 'publ_start' ] . ' - ' . $section[ 'publ_end' ];
		 endif;

		// Block: Content | Modul: menu_link | ID: 3 | NAME: no name | Valid: from-to date
		$section[ 'SHOW' ]	=         $MOD_ANCHOR['block']  . ' ' . $section[ 'BLOCK' ]
							. ' | ' . $MOD_ANCHOR['module'] . ' ' . $section[ 'module' ]
							. ' | ' . $MOD_ANCHOR['id']     . ' ' . $section[ 'section_id' ]
							. ' | ' . $MOD_ANCHOR['name']   . ' ' . $section[ 'name' ]
							. $valid
							;
	}
endif;


/** ------------------------------------------------------------------------------------
 * get block info from template
 * @return	array		$section as reference
 * @param	array		$page
 * @param	array		$section
 * @param	array		$anchor_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'anchor_get_section_block' ) == FALSE ):
	function anchor_get_section_block( $page, &$section, $anchor_vars )
	{
		// get globals
		global $anchor_templateInfo;
		$templateInfo = $anchor_templateInfo;
		$saveglobal = 'global';

		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if ( count( $anchor_vars ) > 0 ):
			$templateInfo = array();
			if ( array_key_exists( 'templateInfo', $anchor_vars ) == TRUE ):
				$templateInfo = $anchor_vars[ 'templateInfo' ];
			endif;
			$saveglobal = 'vars';
		endif;

		// define template to be used
		$template = DEFAULT_TEMPLATE;	// use generic template
		if ( empty( $page['template'] ) == FALSE ):
			$template = $page['template'];	// use page specific template
		endif;

		// check if cache info is already available
		if ( array_key_exists( $template, $templateInfo ) == FALSE ):
			$file_name = LEPTON_PATH . DIRECTORY_SEPARATOR . 'templates' . DIRECTORY_SEPARATOR . $template . DIRECTORY_SEPARATOR . 'info.php';
			if ( file_exists( $file_name ) == TRUE ):
				// load the template
				require( $file_name );

				// cache template info
				$templateInfo[ $template ] = $block;
			endif;
		else:
			$saveglobal = 'none';
		endif;

		// get block name
		if ( array_key_exists( $section['block'], $templateInfo[ $template ] ) == TRUE ):
			$section[ 'BLOCK' ] = $templateInfo[ $template ][ $section['block'] ];
		else:
			$section[ 'BLOCK' ] = '';
		endif;

		// save templateinfo
		switch ( $saveglobal ):
		case 'global':
			$anchor_templateInfo = $templateInfo;
			break;
		case 'vars':
			$anchor_vars[ 'templateInfo' ] = $templateInfo;
			break;
		endswitch;

	}
endif;


/** ------------------------------------------------------------------------------------
 * complete sectionlist
 * @return	array		$list
 * @param	int			$page_id
 * @param	array		$list
 * param	int			$isDisabled
 * @param	array		$anchor_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'anchor_finalize_section_list' ) == FALSE ):
	function anchor_finalize_section_list( $page_id, $list, $isDisabled, $anchor_vars )
	{
		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $anchor_vars ) > 0 )
		and ( array_key_exists( 'MOD_ANCHOR', $anchor_vars ) == TRUE )):
			$MOD_ANCHOR = $anchor_vars[ 'MOD_ANCHOR' ];
		endif;

		// init return
		$result = array();

		// data available
		if (( count( $list ) > 0 )
		and ( array_key_exists( 'section', $MOD_ANCHOR ) == TRUE )):
			// !! Do not use array_merge as it does not preserve numeric key values
			// which might be the case if keyPrefix is '' !!!
			$result = array( '0' => $MOD_ANCHOR['section'] ) + $list;
		elseif (( $page_id == 0 )
			and ( array_key_exists( 'mainselect', $MOD_ANCHOR ) == TRUE )):
			$result[''] = $MOD_ANCHOR['mainselect'];
		elseif (( $isDisabled > 0 )
			and ( array_key_exists( 'dissection', $MOD_ANCHOR ) == TRUE )):
			$result[''] = $MOD_ANCHOR['dissection'];
		elseif ( array_key_exists( 'nosection', $MOD_ANCHOR ) == TRUE ):
			$result[''] = $MOD_ANCHOR['nosection'];
		endif;

		// return the result list
		return($result);
	}
endif;

?>
